window.Gleam.initSearch([{"doc":"html_components","title":"html_components","content":"# HTML components for gleam\n\n[![Package Version](https://img.shields.io/hexpm/v/html_components)](https://hex.pm/packages/html_components)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/html_components/)\n\nGenerate HTML (or XML) from simple gleam functions\n\nFurther documentation can be found at &lt;https://hexdocs.pm/html_components&gt;.\n\n## Getting Started\n\n### Installation\n\n```sh\ngleam add html_components\n```\n\n### Usage\n\n#### HTML\n\n```gleam\nimport elements\nimport html\nimport render\n\nlet input =\n  html.html([elements.attr(&quot;lang&quot;, &quot;en&quot;)], [\n    html.head([], [html.title(&quot;Nested&quot;)]),\n    html.body([], [\n      html.h1([], [elements.text(&quot;Hello&quot;)]),\n      html.div([elements.attr(&quot;class&quot;, &quot;text-2xl&quot;)], [\n        html.p([], [elements.text(&quot;What a nice library&quot;)]),\n      ]),\n    ]),\n  ])\n\nrender.html(input)\n// &lt;!DOCTYPE html&gt;&lt;html lang=&quot;en&quot;&gt;&lt;head&gt;&lt;title&gt;Nested&lt;/title&gt;&lt;/head&gt;&lt;body&gt;&lt;h1&gt;Hello&lt;/h1&gt;&lt;div class=&quot;text-2xl&quot;&gt;&lt;p&gt;What a nice library&lt;/p&gt;&lt;/div&gt;&lt;/body&gt;&lt;/html&gt;\n```\n\n#### XML\nSince the functions are quite generic, its also possible to generate xml\n\n```gleam\nimport elements\nimport render\n\nlet book_element = fn(id: String, author: String, title: String) {\n  elements.element(&quot;book&quot;, [elements.attr(&quot;id&quot;, id)], [\n    elements.element(&quot;author&quot;, [], [elements.text(author)]),\n    elements.element(&quot;title&quot;, [], [elements.text(title)]),\n  ])\n}\n\nlet books_element = fn(books) { elements.element(&quot;books&quot;, [], books) }\n\nlet input =\n  books_element([\n    book_element(&quot;1&quot;, &quot;J. K. Rowling&quot;, &quot;Philosopher&#39;s Stone&quot;),\n    book_element(&quot;2&quot;, &quot;Douglas Adams&quot;, &quot;The Hitchhiker&#39;s Guide to the Galaxy&quot;)\n  ])\n\nrender.xml(input)\n// &lt;?xml version=&quot;1.0&quot; encoding=&quot;UTF-8&quot;?&gt;&lt;books&gt;&lt;book id=&quot;1&quot;&gt;&lt;author&gt;J. K. Rowling&lt;/author&gt;&lt;title&gt;Philosopher&amp;#x27;s Stone&lt;/title&gt;&lt;/book&gt;&lt;book id=&quot;2&quot;&gt;&lt;author&gt;Douglas Adams&lt;/author&gt;&lt;title&gt;The Hitchhiker&amp;#x27;s Guide to the Galaxy&lt;/title&gt;&lt;/book&gt;&lt;/books&gt;\n```\n\n## Development\n\nFork the project and clone it\n\nYou can run the tests with:\n\n```sh\ngleam test\n```\n","url":"index.html"},{"doc":"elements","title":"Attribute","content":"pub type Attribute {\n  Attribute(key: String, value: String)\n}\n\nAttribute(key: String, value: String)\n\n\nSynonyms:\nelements.Attribute\nelements Attribute","url":"elements.html#Attribute"},{"doc":"elements","title":"Element","content":"pub type Element {\n  Element(\n    tag: String,\n    attrs: List(Attribute),\n    children: List(Element),\n  )\n  Text(String)\n  CData(String)\n}\n\nElement(\n  tag: String,\n  attrs: List(Attribute),\n  children: List(Element),\n)\n\n\nText(String)\n\n\nCData(String)\n\n\nSynonyms:\nelements.Element\nelements Element","url":"elements.html#Element"},{"doc":"elements","title":"attr","content":"pub fn attr(key: String, value: String) -&gt; Attribute\n\nSynonyms:\nelements.attr\nelements attr","url":"elements.html#attr"},{"doc":"elements","title":"cdata","content":"pub fn cdata(value: String) -&gt; Element\n\nSynonyms:\nelements.cdata\nelements cdata","url":"elements.html#cdata"},{"doc":"elements","title":"element","content":"pub fn element(\n  tag: String,\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nelements.element\nelements element","url":"elements.html#element"},{"doc":"elements","title":"element_self_closing","content":"pub fn element_self_closing(\n  tag: String,\n  attrs: List(Attribute),\n) -&gt; Element\n\nSynonyms:\nelements.element_self_closing\nelements element_self_closing","url":"elements.html#element_self_closing"},{"doc":"elements","title":"text","content":"pub fn text(value: String) -&gt; Element\n\nSynonyms:\nelements.text\nelements text","url":"elements.html#text"},{"doc":"elements","title":"elements","content":"","url":"elements.html"},{"doc":"html","title":"a","content":"pub fn a(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.a\nhtml a","url":"html.html#a"},{"doc":"html","title":"body","content":"pub fn body(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.body\nhtml body","url":"html.html#body"},{"doc":"html","title":"div","content":"pub fn div(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.div\nhtml div","url":"html.html#div"},{"doc":"html","title":"document","content":"pub fn document(\n  attrs: List(Attribute),\n  head_elements: List(Element),\n  body_elements: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.document\nhtml document","url":"html.html#document"},{"doc":"html","title":"h1","content":"pub fn h1(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.h1\nhtml h1","url":"html.html#h1"},{"doc":"html","title":"h2","content":"pub fn h2(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.h2\nhtml h2","url":"html.html#h2"},{"doc":"html","title":"h3","content":"pub fn h3(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.h3\nhtml h3","url":"html.html#h3"},{"doc":"html","title":"h4","content":"pub fn h4(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.h4\nhtml h4","url":"html.html#h4"},{"doc":"html","title":"h5","content":"pub fn h5(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.h5\nhtml h5","url":"html.html#h5"},{"doc":"html","title":"head","content":"pub fn head(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.head\nhtml head","url":"html.html#head"},{"doc":"html","title":"html","content":"pub fn html(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.html\nhtml html","url":"html.html#html"},{"doc":"html","title":"meta","content":"pub fn meta(attrs: List(Attribute)) -&gt; Element\n\nSynonyms:\nhtml.meta\nhtml meta","url":"html.html#meta"},{"doc":"html","title":"p","content":"pub fn p(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.p\nhtml p","url":"html.html#p"},{"doc":"html","title":"span","content":"pub fn span(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.span\nhtml span","url":"html.html#span"},{"doc":"html","title":"title","content":"pub fn title(title: String) -&gt; Element\n\nSynonyms:\nhtml.title\nhtml title","url":"html.html#title"},{"doc":"html","title":"html","content":"","url":"html.html"},{"doc":"render","title":"element","content":"pub fn element(el: Element) -&gt; String\n\nSynonyms:\nrender.element\nrender element","url":"render.html#element"},{"doc":"render","title":"escape","content":"pub fn escape(value: String) -&gt; String\n\nSynonyms:\nrender.escape\nrender escape","url":"render.html#escape"},{"doc":"render","title":"html","content":"pub fn html(el: Element) -&gt; String\n\nSynonyms:\nrender.html\nrender html","url":"render.html#html"},{"doc":"render","title":"xml","content":"pub fn xml(el: Element) -&gt; String\n\nSynonyms:\nrender.xml\nrender xml","url":"render.html#xml"},{"doc":"render","title":"render","content":"","url":"render.html"}]);